@@ -140,6 +140,7 @@ modern_classmap = [(u'valo', u'sw', [(None,u'(.*)',u'valo'),
 			(u'kk',u'(.*k)kA',u'haka'),
 			(u'p',u'(.*)pA',u'napa'),
 			(u't',u'(.*)tA',u'pata'),
+			(u'k>j',u'(.*A)ikA',u'aika'),
 			(u'k>',u'(.*AA)kA',u'raaka'),
 			(u'k>',u'(.*)kA',u'haka')]),
 	(u'koira', u'sw',   [(None,u'(.*)A',u'koira'),
@@ -196,8 +197,10 @@ modern_classmap = [(u'valo', u'sw', [(None,u'(.*)',u'valo'),
 	(u'rosé', u'-', [(None,u'(.*V)',u'rosé')]),
 	(u'parfait', u'-', [(None,u'(.*VC)',u'parfait')]),
 	(u'huuli', u'-', [(None,u'(.*C)i',u'tuohi')]),
+	(u'meri', u'-', [(None,u'(.*er)i',u'meri')]),
 	(u'tuohi', u'-', [(None,u'(.*C)i',u'lohi')]),
 	(u'niemi', u'-', [(None,u'(.*V)mi',u'niemi')]),
+	(u'pieni', u'-', [(None,u'(.*n)i',u'pieni')]),
 	(u'lumi', u'-', [(None,u'(.*V)mi',u'lumi')]),
 	(u'susi', u'-', [(None,u'(.*V)si',u'susi')]),
 	(u'kansi', u'-', [(None,u'(.*n)si',u'kansi'),
